@@ -4,7 +4,7 @@ C PART II: SOBOL SEQUENCE
 
 C ##############################################################################
 C PART I: HALTON SEQUENCE:
- 
+C ############################################################################## 
 
 C-------------------------------------------------------------------------- 
 C @file  LowDiscrepancy.f
@@ -13,9 +13,13 @@ C
 C @author Diethelm Wuertz 
 C @author Christophe Dutang
 C
+C Copyright (C) Apr. 2011, Christophe Dutang, remove implicit declaration: the code now pass
+C > gfortran -c -fsyntax-only -fimplicit-none LowDiscrepancy.f 
+C without error.
+C
+C Copyright (C) Oct. 2009, Christophe Dutang, slightly modified (better accuracy and speed).
 C
 C Copyright (C) Sept. 2002, Diethelm Wuertz, ETH Zurich. All rights reserved.
-C slightly modified (better accuracy and speed) by Christophe Dutang in October 2009.
 C
 C The new BSD License is applied to this software.
 C Copyright (c) Diethelm Wuertz, ETH Zurich. All rights reserved.
@@ -67,7 +71,10 @@ C     THE BASE IS CALCULATED FROM PRIMES
       INTEGER DIMEN, BASE(DIMEN), ITER(DIMEN), OFFSET, DIGIT
       DOUBLE PRECISION QUASI(DIMEN), HALF
       INTRINSIC MOD
- 
+	  
+C	  >>> remove implicit type declaration <<<	  
+      INTEGER N, NC, NB, M, K, I
+	   	  
 C     INIT BASE FROM PRIMES - THIS IMPLEMENTS A SIMMPLE SIEVE:
       BASE(1) = 2
       BASE(2) = 3
@@ -120,6 +127,9 @@ C     NOTE, THAT WE HAVE ALREADY "OFFSET" POINTS GENERATED.
       INTEGER DIMEN, BASE(DIMEN), ITER(DIMEN), OFFSET, DIGIT
       DOUBLE PRECISION QUASI(DIMEN), HALF
       INTRINSIC MOD
+	  
+C	  >>> remove implicit type declaration <<<	  
+	  INTEGER NB                                                        
            
       DO NB = 1, DIMEN      
       ITER(NB) = OFFSET
@@ -159,6 +169,10 @@ C       TRANSFORM - A FLAG, 0 FOR UNIFORM, 1 FOR NORMAL DISTRIBUTION
       INTEGER N, DIMEN, OFFSET, INIT, TRANSFORM
       INTEGER BASE(DIMEN)
       DOUBLE PRECISION QN(N,DIMEN), QUASI(DIMEN)
+	  
+C	  >>> remove implicit type declaration <<<	  
+	  INTEGER I, J
+	  DOUBLE PRECISION HQNORM
 
 C     IF REQUESTED, INITIALIZE THE GENERATOR:
       IF (INIT.EQ.1) THEN
@@ -193,11 +207,24 @@ C ------------------------------------------------------------------------------
 
 C     USED TO CALCULATE HALTON NORMAL DEVIATES:
       DOUBLE PRECISION P,R,T,A,B, EPS
-      DATA P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
-     &   /-0.322232431088E+0, -1.000000000000E+0, -0.342242088547E+0, 
-     &    -0.204231210245E-1, -0.453642210148E-4, +0.993484626060E-1,
-     &    +0.588581570495E+0, +0.531103462366E+0, +0.103537752850E+0,  
-     &    +0.385607006340E-2  /
+	  
+C      DATA P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
+C     &   /-0.322232431088E+0, -1.000000000000E+0, -0.342242088547E+0, 
+C     &    -0.204231210245E-1, -0.453642210148E-4, +0.993484626060E-1,
+C     &    +0.588581570495E+0, +0.531103462366E+0, +0.103537752850E+0,  
+C     &    +0.385607006340E-2  /
+C	  >>> remove implicit type declaration <<<
+	  DOUBLE PRECISION P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
+	  P0 = -0.322232431088E+0 
+	  P1 = -1.000000000000E+0 
+	  P2 = -0.342242088547E+0 
+	  P3 = -0.204231210245E-1 
+	  P4 = -0.453642210148E-4 
+	  Q0 = +0.993484626060E-1
+	  Q1 = +0.588581570495E+0 
+	  Q2 = +0.531103462366E+0 
+	  Q3 = +0.103537752850E+0  
+	  Q4 = +0.385607006340E-2
 
 C     NOTE, IF P BECOMES 1, THE PROGRAM FAILS TO CALCULATE THE
 C     NORMAL RDV. IN THIS CASE WE REPLACE THE LOW DISCREPANCY 
@@ -229,6 +256,9 @@ C -----------------------------------------------------------------------------
       PARAMETER (N1=20,N2=N1/2,DIMEN=5)
       INTEGER BASE(DIMEN)
       DOUBLE PRECISION QN1(N1,DIMEN),QN2(N2,DIMEN)
+	  
+C	  >>> remove implicit type declaration <<<
+	  INTEGER INIT, I, J	
 
       TRANSFORM = 0
       
@@ -284,6 +314,7 @@ c      end
 
 C ##############################################################################
 C PART II: SOBOL SEQUENCE:
+C ##############################################################################
 
 
 C-------------------------------------------------------------------------- 
@@ -309,8 +340,13 @@ C       http://www.acm.org/pubs/copyright_policy/softwareCRnotice.html
 C
 C @author Christophe Dutang
 C
+C Copyright (C) Apr. 2011, Christophe Dutang, remove implicit declaration: the code now pass
+C > gfortran -c -fsyntax-only -fimplicit-none LowDiscrepancy.f 
+C without error.
+C
+C Copyright (C) Oct. 2009, Christophe Dutang, slightly modified (better accuracy and speed).
+C
 C Copyright (C) Sept. 2002, Diethelm Wuertz, ETH Zurich. All rights reserved.
-C slightly modified (better accuracy and speed) by Christophe Dutang in October 2009.
 C
 C The new BSD License is applied to this software.
 C Copyright (c) Diethelm Wuertz, ETH Zurich. All rights reserved.
@@ -384,6 +420,10 @@ C       TRANSFORM - FLAG, 0 FOR UNIFORM, 1 FOR NORMAL DISTRIBUTION
       INTEGER LL,COUNT,SV(DIMEN,MAXBIT)
       DOUBLE PRECISION QN(N,DIMEN), QUASI(DIMEN)
       INTEGER iSEED
+	  
+C	  >>> remove implicit type declaration <<<
+	  INTEGER I, J, IFLAG
+	  DOUBLE PRECISION SQNORM
 
       IF (INIT.EQ.1) THEN
 		  CALL INITSOBOL(DIMEN, QUASI, LL, COUNT, SV, IFLAG, iSEED)  
@@ -418,11 +458,25 @@ C ------------------------------------------------------------------------------
 
 C     USED TO CALCULATE SOBOL NORMAL DEVIATES
       DOUBLE PRECISION P,R,T,A,B, EPS
-      DATA P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
-     &   /-0.322232431088E+0, -1.000000000000E+0, -0.342242088547E+0, 
-     &    -0.204231210245E-1, -0.453642210148E-4, +0.993484626060E-1,
-     &    +0.588581570495E+0, +0.531103462366E+0, +0.103537752850E+0,  
-     &    +0.385607006340E-2  /
+	  
+C      DATA P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
+C     &   /-0.322232431088E+0, -1.000000000000E+0, -0.342242088547E+0, 
+C     &    -0.204231210245E-1, -0.453642210148E-4, +0.993484626060E-1,
+C     &    +0.588581570495E+0, +0.531103462366E+0, +0.103537752850E+0,  
+C     &    +0.385607006340E-2  /
+C	  >>> remove implicit type declaration <<<
+	  DOUBLE PRECISION P0,P1,P2,P3,P4, Q0,Q1,Q2,Q3,Q4
+	  P0 = -0.322232431088E+0 
+	  P1 = -1.000000000000E+0 
+	  P2 = -0.342242088547E+0
+	  P3 = -0.204231210245E-1 
+	  P4 = -0.453642210148E-4 
+	  Q0 = +0.993484626060E-1
+	  Q1 = +0.588581570495E+0 
+	  Q2 = +0.531103462366E+0 
+	  Q3 = +0.103537752850E+0  
+	  Q4 = +0.385607006340E-2
+	 
 
 C     NOTE, IF P BECOMES 1, THE PROGRAM FAILS TO CALCULATE THE
 C     NORMAL RDV. IN THIS CASE WE REPLACE THE LOW DISCREPANCY 
@@ -490,6 +544,8 @@ CC      INTEGER TEMP1,TEMP2,TEMP4
       INTEGER iSEED
       LOGICAL INCLUD(MAXDEG)
       INTRINSIC MOD, IEOR
+	  
+	  
       
       DATA (POLY(I),I=2,211)/3,7,11,13,19,25,37,59,47,61,55,41,67,97,91,
      +     109,103,115,131,193,137,145,143,241,157,185,167,229,171,213,
@@ -1301,6 +1357,10 @@ CC      INTEGER TEMP1,TEMP2,TEMP4
      +     6737,2995,7235,7713,973,4821,2377,1673,1,6541/
       
       DATA TAU/0,0,1,3,5,8,11,15,19,23,27,31,35/
+	  
+C	  >>> remove implicit type declaration <<<
+	  INTEGER MAXX, MAX, LL, TEMP01
+	  
 
 C     CHECK PARAMETERS:
       MAX = 30
@@ -1582,6 +1642,9 @@ C       COUNT     - SEQUENCE NUMBER OF THE CALL
       INTEGER SV(DIMEN,MAXBIT)
       DOUBLE PRECISION QUASI(DIMEN)
       INTRINSIC MOD, IEOR
+	  
+C	  >>> remove implicit type declaration <<<
+	  INTEGER LL
       
       L = 0
       I = COUNT
@@ -1609,10 +1672,16 @@ C ------------------------------------------------------------------------------
 
 C     TESTROUTINE, CALLED FROM THE FORTRAN MAIN PROGRAM
       INTEGER MAXBIT,DIMEN,TRANSFORM
+C	  >>> remove implicit type declaration <<<
+	  INTEGER N1, N2
       PARAMETER (N1=20,N2=N1/2,DIMEN=5,MAXBIT=30)
       INTEGER LL,COUNT,SV(DIMEN,MAXBIT)
       DOUBLE PRECISION QN1(N1,DIMEN),QN2(N2,DIMEN),QUASI(DIMEN)
       INTEGER iSEED, iSEED1
+	  
+C	  >>> remove implicit type declaration <<<
+	  INTEGER IFLAG, I, J, INIT
+	  
 
       TRANSFORM = 1
       IFLAG = 3
